-- version 1.09
-- Base de donnes: opencimetiere
-- cle secondaire
-------- parametrage collectivite ----------------------------------------
CREATE TABLE collectivite (
  ville varchar(30) NOT NULL default '',
  logo varchar(40),
  maire varchar(40),
  id int8,
  PRIMARY KEY  (id)
);
INSERT INTO collectivite VALUES ('Libreville', '../img/opencimetiere.png', 'H.DUPONT', 0);
-- ----- gestion des droits -----------------------------------------------
CREATE TABLE profil (
  profil int8 NOT NULL default '0',
  libelle_profil varchar(30),
  PRIMARY KEY  (profil)
);

INSERT INTO profil VALUES (5, 'ADMINISTRATEUR');
INSERT INTO profil VALUES (4, 'SUPER UTILISATEUR');
INSERT INTO profil VALUES (3, 'UTILISATEUR');
INSERT INTO profil VALUES (2, 'UTILISATEUR LIMITE');
INSERT INTO profil VALUES (1, 'CONSULTATION');

CREATE TABLE droit (
  droit varchar(30) NOT NULL default '',
  profil int8 REFERENCES profil (profil),
  PRIMARY KEY  (droit)
);

INSERT INTO droit VALUES ('utilisateur', 5);
INSERT INTO droit VALUES ('droit', 5);
INSERT INTO droit VALUES ('profil', 5);
INSERT INTO droit VALUES ('emplacement', 3);
INSERT INTO droit VALUES ('concession', 3);
INSERT INTO droit VALUES ('ossuaire', 3);
INSERT INTO droit VALUES ('depositoire', 3);
INSERT INTO droit VALUES ('colombarium', 3);
INSERT INTO droit VALUES ('enfeu', 3);
INSERT INTO droit VALUES ('terraincommunal', 3);
INSERT INTO droit VALUES ('cimetiere', 4);
INSERT INTO droit VALUES ('voie', 4);
INSERT INTO droit VALUES ('zone', 4);
INSERT INTO droit VALUES ('plans', 4);
INSERT INTO droit VALUES ('defunt', 3);
INSERT INTO droit VALUES ('concessionnaire', 3);
INSERT INTO droit VALUES ('ayantdroit', 3);
INSERT INTO droit VALUES ('collectivite', 5);

CREATE TABLE utilisateur (
  idUtilisateur int8 NOT NULL,
  nom varchar(30),
  Login varchar(30),
  Pwd varchar(100),
  profil int8 REFERENCES profil (profil),
  PRIMARY KEY  (idUtilisateur)
);
 
INSERT INTO utilisateur VALUES (2, 'demo', 'demo', 'fe01ce2a7fbac8fafaed7c982a04e229', 5);
INSERT INTO utilisateur VALUES (3, 'util', 'util', '05c7e24700502a079cdd88012b5a76d3', 3);

CREATE SEQUENCE utilisateur_seq
  INCREMENT 1
  MINVALUE 1
  MAXVALUE 9223372036854775807
  START 4
  CACHE 1;

------- Emplacement ------------------------------------------------------------

CREATE TABLE plans (
  plans varchar(20) NOT NULL default '',
  planslib varchar(40),
  PRIMARY KEY  (plans)
);

CREATE TABLE cimetiere (
  cimetiere int8 NOT NULL,
  cimetierelib varchar(40),
  adresse1 varchar(40),
  adresse2 varchar(40),
  cp varchar(5),
  ville varchar(40),
  observations text ,
  PRIMARY KEY  (cimetiere)
);

CREATE TABLE zone (
  zone int8 NOT NULL,
  cimetiere int8 REFERENCES cimetiere (cimetiere),
  zonetype varchar(30),
  zonelib varchar(40),
  PRIMARY KEY  (zone)
);

CREATE TABLE voie (
  voie int8 NOT NULL,
  zone int8 REFERENCES zone (zone),
  voietype varchar(30),
  voielib varchar(40),
  PRIMARY KEY  (voie)
);

CREATE TABLE emplacement (
  emplacement int8 NOT NULL default '0',
  nature varchar(20),
  numero int8 ,
  complement varchar(6),
  voie int8 REFERENCES voie (voie),
  numerocadastre varchar(15),
  famille varchar(40),
  numeroacte varchar(15),
  datevente date,
  terme varchar(15) ,
  duree real ,
  dateterme date,
  nombreplace real ,
  placeoccupe real ,
  superficie real ,
  placeconstat real ,
  dateconstat date,
  observation text,
  plans varchar(30),
  positionx real,
  positiony real,
  photo varchar(20),
  libre char(3),
  sepulturetype varchar(30),
  temp1 varchar(100),
  temp2 varchar(100),
  temp3 varchar(100),
  temp4 varchar(100),
  temp5 varchar(100),
  PRIMARY KEY  (emplacement)
);

CREATE SEQUENCE emplacement_seq
  INCREMENT 1
  MINVALUE 1
  MAXVALUE 9223372036854775807
  START 1
  CACHE 1;


-------- autorisation defunt courrier dossier-----------------------------------

CREATE TABLE autorisation (
  autorisation int8 NOT NULL,
  emplacement int8 REFERENCES emplacement (emplacement),
  nature varchar(15),
  titre varchar(4),
  nom varchar(40),
  marital varchar(40),
  prenom varchar(40),
  datenaissance date,
  adresse1 varchar(40),
  adresse2 varchar(40),
  cp varchar(5),
  ville varchar(40),
  telephone varchar(15),
  dcd char(3),
  parente varchar(15),
  observation text,
  PRIMARY KEY  (autorisation)
);

CREATE SEQUENCE autorisation_seq
  INCREMENT 1
  MINVALUE 1
  MAXVALUE 9223372036854775807
  START 1
  CACHE 1;

--

CREATE TABLE courrier (
  courrier int8 NOT NULL default '0',
  destinataire int8,
  datecourrier date,
  lettretype varchar(40),
  complement text,
  emplacement int8 REFERENCES emplacement (emplacement),
  PRIMARY KEY  (courrier)
) ;

CREATE TABLE defunt (
  defunt int8 NOT NULL default '0',
  nature varchar(15),
  taille real,
  emplacement int8 REFERENCES emplacement (emplacement),
  titre varchar(4),
  nom varchar(40) ,
  prenom varchar(40),
  marital varchar(40),
  datenaissance date,
  datedeces date,
  lieudeces varchar(40),
  dateinhumation date,
  exhumation char(3),
  dateexhumation date,
  observation text,
  reduction char(3),
  datereduction date,
  historique text,
  PRIMARY KEY  (defunt)
);

CREATE SEQUENCE defunt_seq
  INCREMENT 1
  MINVALUE 1
  MAXVALUE 9223372036854775807
  START 1
  CACHE 1;

CREATE TABLE dossier (
dossier int8 NOT NULL ,
emplacement int8 REFERENCES emplacement (emplacement),
fichier VARCHAR(40),
datedossier DATE,
observation text,
typedossier VARCHAR(20),
PRIMARY KEY (dossier)
);

CREATE SEQUENCE dossier_seq
  INCREMENT 1
  MINVALUE 1
  MAXVALUE 9223372036854775807
  START 1
  CACHE 1;
  
-- travaux   -------------------------------------------------------------------

CREATE TABLE entreprise (
idintervenant int8 NOT NULL ,
nomentreprise varchar(60) NOT NULL ,
adresse1 varchar(40) NOT NULL ,
adresse2 varchar(40) NOT NULL ,
cp varchar(5) NOT NULL ,
ville varchar(40) NOT NULL ,
telephone varchar(40) NOT NULL ,
PRIMARY KEY (idintervenant)
);

CREATE SEQUENCE entreprise_seq
  INCREMENT 1
  MINVALUE 1
  MAXVALUE 9223372036854775807
  START 1
  CACHE 1;
  
CREATE TABLE travaux (
idtravaux int8 NOT NULL ,
idintervenant int8 REFERENCES entreprise (idintervenant),
emplacement int8 REFERENCES emplacement (emplacement),
datedebinter date,
datefininter date,
observation text,
naturedemandeur varchar(20),
naturetravaux varchar(40),
PRIMARY KEY (idtravaux) 
);

CREATE SEQUENCE travaux_seq
  INCREMENT 1
  MINVALUE 1
  MAXVALUE 9223372036854775807
  START 1
  CACHE 1;
  

  
-- archives --------------------------------------------------------------------
-- pas de protection cle secondaire en base

CREATE TABLE autorisation_archive (
autorisation int8 NOT NULL default '0',
emplacement int8 ,
nature varchar(15),
titre varchar(4),
nom varchar(40),
marital varchar(40),
prenom varchar(40),
datenaissance date,
adresse1 varchar(40),
adresse2 varchar(40),
cp varchar(5),
ville varchar(40),
telephone varchar(15),
dcd char(3),
parente varchar(15),
observation text,
PRIMARY KEY (autorisation) 
);
CREATE TABLE defunt_archive (
defunt int8 NOT NULL default '0',
nature varchar(15),
taille real,
emplacement int8 ,
titre varchar(4),
nom varchar(40),
prenom varchar(40),
marital varchar(40),
datenaissance date,
datedeces date,
lieudeces varchar(40),
dateinhumation date,
exhumation char(3),
dateexhumation date,
observation text,
reduction char(3),
datereduction date,
historique text,
PRIMARY KEY (defunt) 
) ;
CREATE TABLE emplacement_archive (
emplacement int8 NOT NULL default '0',
nature varchar(20),
numero int8 ,
complement varchar(6),
voie int8 ,
numerocadastre varchar(15),
famille varchar(40),
numeroacte varchar(15),
datevente date,
terme varchar(20) ,
duree real ,
dateterme date,
nombreplace real,
placeoccupe real,
superficie real,
placeconstat real,
dateconstat date,
observation text,
plans varchar(30),
positionx real,
positiony real,
photo varchar(20),
libre char(3),
sepulturetype varchar(30),
PRIMARY KEY (emplacement) 
);
CREATE TABLE travaux_archive (
idtravaux int8 NOT NULL default '0',
idintervenant int8 ,
emplacement int8 ,
datedebinter date,
datefininter date,
observation text NOT NULL ,
naturedemandeur varchar(20),
naturetravaux varchar(40),
PRIMARY KEY (idtravaux) 
);
CREATE TABLE courrier_archive (
courrier int8 NOT NULL default '0',
destinataire int8 ,
datecourrier date,
lettretype varchar(40),
complement text,
emplacement int8 ,
PRIMARY KEY (courrier) 
); 
CREATE TABLE dossier_archive (
dossier int8 NOT NULL ,
emplacement int8,
fichier VARCHAR(40),
datedossier DATE,
observation text,
typedossier varchar(20),
PRIMARY KEY (dossier)
);

-- --------------------------------------------------------

--
-- Structure de la table `temp_autorisation`
--

CREATE TABLE temp_autorisation (
  id int8 NOT NULL default '0',
  emplacement int8 NOT NULL default '0',
  autorisation int8 NOT NULL default '0',
  nature varchar(15) NOT NULL default '',
  titre varchar(4) NOT NULL default '',
  nom varchar(40) NOT NULL default '',
  marital varchar(40) NOT NULL default '',
  prenom varchar(40) NOT NULL default '',
  datenaissance varchar(10) NOT NULL default '',
  numero varchar(10) NOT NULL default '',
  complement varchar(15) NOT NULL default '',
  adresse1 varchar(80) NOT NULL default '',
  adresse2 varchar(80) NOT NULL default '',
  cp varchar(5) NOT NULL default '',
  ville varchar(40) NOT NULL default '',
  telephone varchar(15) NOT NULL default '',
  dcd char(3) NOT NULL default '',
  parente varchar(15) NOT NULL default '',
  temp_emplacement varchar(80) NOT NULL default '',
  temp_cimetiere varchar(10) NOT NULL default '',
  verrou char(3) NOT NULL default 'Non',
  PRIMARY KEY  (id)
) ;
    
-- --------------------------------------------------------

--
-- Structure de la table temp_defunt
--

CREATE TABLE temp_defunt (
  id int8 NOT NULL default '0',
  defunt int8 NOT NULL default '0',
  nature varchar(15) NOT NULL default '',
  taille float NOT NULL default '0',
  emplacement int8 NOT NULL default '0',
  titre varchar(4) NOT NULL default '',
  nom varchar(40) NOT NULL default '',
  prenom varchar(40) NOT NULL default '',
  marital varchar(40) NOT NULL default '',
  datenaissance varchar(10) NOT NULL default '',
  datedeces varchar(10) NOT NULL default '',
  lieudeces varchar(40) NOT NULL default '',
  dateinhumation varchar(10) NOT NULL default '',
  exhumation char(3) NOT NULL default '',
  dateexhumation varchar(10) NOT NULL default '',
  observation text NOT NULL,
  reduction char(3) NOT NULL default '',
  datereduction varchar(10) NOT NULL default '',
  temp_emplacement varchar(80) NOT NULL default '',
  temp_cimetiere int8 NOT NULL default '0',
  verrou char(3) NOT NULL default 'Non',
  PRIMARY KEY  (id)
) ;

-- --------------------------------------------------------

--
-- Structure de la table temp_emplacement
--

CREATE TABLE temp_emplacement (
  id int8 NOT NULL default '0',
  emplacement int8 NOT NULL default '0',
  nature varchar(20) NOT NULL default '',
  numero int8 NOT NULL default '0',
  complement varchar(6) NOT NULL default '',
  voie int8 NOT NULL default '0',
  numerocadastre varchar(15) NOT NULL default '',
  famille varchar(40) NOT NULL default '',
  numeroacte varchar(15) NOT NULL default '',
  datevente varchar(10) NOT NULL default '',
  terme varchar(15) NOT NULL default '0',
  duree varchar(15) NOT NULL default '0',
  dateterme varchar(10) NOT NULL default '',
  nombreplace float NOT NULL default '0',
  placeoccupe float NOT NULL default '0',
  superficie float NOT NULL default '0',
  placeconstat float NOT NULL default '0',
  dateconstat varchar(10) NOT NULL default '',
  observation text NOT NULL,
  plans varchar(30) NOT NULL default '',
  positionx int8 NOT NULL default '10',
  positiony int8 NOT NULL default '10',
  photo varchar(80) NOT NULL default '',
  p_dossier varchar(15) NOT NULL default '',
  acteconcession varchar(40) NOT NULL default '',
  d_dossier1 varchar(15) NOT NULL default '',
  fichemanuelle varchar(40) NOT NULL default '',
  d_dossier2 varchar(15) NOT NULL default '',
  archive varchar(40) NOT NULL default '',
  d_dossier3 varchar(15) NOT NULL default '',
  libre char(3) NOT NULL default '',
  sepulturetype varchar(30) NOT NULL default '',
  temp_emplacement varchar(80) NOT NULL default '',
  temp_zone varchar(80) NOT NULL default '',
  temp_voie varchar(80) NOT NULL default '',
  temp_numero varchar(80) NOT NULL default '',
  temp_cimetiere varchar(80) NOT NULL default '',
  verrou char(3) NOT NULL default 'Non',
  PRIMARY KEY  (id)
) ;